# frozen_string_literal: true

module Hermes
  # Applicant links for coapplicants relation
  class ApplicantLink
    include Hermes::Concerns::CommonFieldsConcern
    field :type, type: String # nom de la relation : conjoint / paxé / colocataire
    field :is_active, type: Boolean, default: true
    field :applicant_ids, type: Array, default: [] # tableau des applicants dans la relation

    belongs_to :housing_request, index: true, class_name: 'Hermes::HousingRequest'
    # has_and_belongs_to_many :applicants, class_name: 'Hermes::Applicant', inverse_of: nil

    common_indexes *%i[
      type
      is_active
      applicant_ids
    ]

    default_scope { where(is_active: true) }

    validates_presence_of :housing_request_id
    before_save :before_save_actions
    after_save :after_save_actions

    def before_save_actions
      self.is_active = applicant_ids.present?
      true
    end

    def after_save_actions
      housing_request&.save if activity_or_applicants_changed?
    end

    def activity_or_applicants_changed?
      is_active_changed? || applicant_ids_changed?
    end
  end
end
