require 'rails_helper'

RSpec.describe Hermes::Lessor, type: :model do
  it 'has a valid factory' do
    expect(FactoryBot.build(:lessor)).to be_valid
  end
  
  # describe 'validate title presence' do
  #   it 'is invalid without a title' do
  #     expect(FactoryBot.build(:lessor, title: nil)).not_to be_valid
  #   end
  # end
  
  let!(:basic_lessor) {create(:lessor)}
  let!(:agency) {create(:entity)}
  describe "standard test données nathanael" do
    let!(:lessor_objective1) do
      create(
        :lessor_objective,
        department: '26',
        threshold_type: nil,
        priority_public: nil,
        operation_name: "",
        target_by_typologies: {"T4"=>15},
        lessor_id: basic_lessor.id,
        activation_date: DateTime.new(DateTime.current.year, 03, 23).utc,
        agency_id: nil,
        test: "1"
      )
    end
    
    describe "logement A ->5" do
      let!(:housing_offerA) do
        create(
          :housing_offer,
          district: 'VALENCE',
          department: '26',
          threshold_type: 'PL4',
          typology: "T4",
          priority_public: nil,
          operation_name: nil,
          lessor_id: basic_lessor.id,
          agency_id: "0206"
        )
      end
      before :each do
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offerA.lessor_status = 'LOUE'
        housing_offerA.save()
      end
      it 'should has updated correctly' do
        expect(lessor_objective1.reload.realized_by_typologies).to eq({"T4" => 0})
      
      end
    end
  end
  describe "standard test données nathanael corrigé" do
    let!(:lessor_objective1) do
      create(
        :lessor_objective,
        department: '26',
        threshold_type: nil,
        priority_public: nil,
        operation_name: nil,
        target_by_typologies: {"T4"=>15},
        lessor_id: basic_lessor.id,
        activation_date: DateTime.new(DateTime.current.year, 03, 23).utc,
        agency_id: nil,
        test: "1"
      )
    end
  
    describe "logement A ->5" do
      let!(:housing_offerA) do
        create(
          :housing_offer,
          district: 'VALENCE',
          department: '26',
          threshold_type: 'PL4',
          typology: "T4",
          priority_public: nil,
          operation_name: nil,
          lessor_id: basic_lessor.id,
          agency_id: "0206"
        )
      end
      before :each do
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offerA.lessor_status = 'LOUE'
        housing_offerA.save()
      end
      it 'should has updated correctly' do
        expect(lessor_objective1.reload.realized_by_typologies).to eq({"T4" => 1})
    
      end
    end
  end
  describe "standard test" do
    let!(:lessor_objective1) do
      create(
        :lessor_objective,
        department: 'Yvelines',
        threshold_type: 'PLUS',
        priority_public: true,
        
        target_by_typologies: {T2: 30},
        lessor_id: basic_lessor.id,
        activation_date: DateTime.new(DateTime.current.year, 5, 5).utc,
        agency_id: agency.id,
        test: "1"
      )
    end
    let!(:lessor_objective2) do
      create(
        :lessor_objective,
        department: 'Yvelines',
        priority_public: false,
        
        target_by_typologies: {T2: 30},
        lessor_id: basic_lessor.id,
        activation_date: DateTime.new(DateTime.current.year, 5, 5).utc,
        agency_id: agency.id,
        test: "2"
      )
    end
    let!(:lessor_objective3) do
      create(
        :lessor_objective,
        district: 'Plaisir',
        department: 'Yvelines',
        threshold_type: 'PLUS',
        priority_public: true,
        
        target_by_typologies: {all: 20},
        lessor_id: basic_lessor.id,
        activation_date: DateTime.new(DateTime.current.year, 5, 5).utc,
        agency_id: agency.id,
        test: "3"
      )
    end
    let!(:lessor_objective4) do
      create(
        :lessor_objective,
        district: 'Plaisir',
        department: 'Yvelines',
        priority_public: true,
        
        target_by_typologies: {T1: 20},
        lessor_id: basic_lessor.id,
        activation_date: DateTime.new(DateTime.current.year, 5, 5).utc,
        agency_id: agency.id,
        test: "4"
      )
    end
    let!(:lessor_objective5) do
      create(
        :lessor_objective,
        district: 'Plaisir',
        department: 'Yvelines',
        priority_public: true,
        
        target_by_typologies: {all: 10},
        operation_name: "Bahamas",
        lessor_id: basic_lessor.id,
        activation_date: DateTime.new(DateTime.current.year, 5, 5).utc,
        agency_id: agency.id,
        test: "5"
      )
    end
    let!(:lessor_objective6) do
      create(
        :lessor_objective,
        district: 'Plaisir',
        department: 'Yvelines',
        threshold_type: 'PLUS',
        priority_public: true,
        
        target_by_typologies: {all: 10},
        operation_name: "Bahamas",
        lessor_id: basic_lessor.id,
        activation_date: DateTime.new(DateTime.current.year, 5, 5).utc,
        agency_id: agency.id,
        test: "6"
      )
    end
    
    describe "logement A ->5" do
      let!(:housing_offerA) do
        create(
          :housing_offer,
          district: 'Plaisir',
          department: 'Yvelines',
          threshold_type: 'PLI',
          typology: "T5",
          priority_public: true,
          operation_name: "Bahamas",
          lessor_id: basic_lessor.id,
          agency_id: agency.id
        )
      end
      before :each do
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offerA.lessor_status = 'LOUE'
        housing_offerA.save()
      end
      it 'should has updated correctly' do
        expect(lessor_objective1.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective2.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective3.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective4.reload.realized_by_typologies).to eq({"T1" => 0})
        expect(lessor_objective5.reload.realized_by_typologies).to eq({"all" => 1})
        expect(lessor_objective6.reload.realized_by_typologies).to eq({"all" => 0})
      end
    
    end
    describe "logement B ->no_obj" do
      let!(:housing_offerL) do
        create(
          :housing_offer,
          district: 'Rambouillet',
          department: 'Yvelines',
          priority_public: false,
          typology: "T5",
          threshold_type: 'PLUS',
          operation_name: "Bahamas",
          lessor_id: basic_lessor.id,
          agency_id: agency.id
        )
      end
      before :each do
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offerL.lessor_status = 'LOUE'
        housing_offerL.save()
      end
      it 'should has updated correctly' do
        expect(lessor_objective1.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective2.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective3.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective4.reload.realized_by_typologies).to eq({"T1" => 0})
        expect(lessor_objective5.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective6.reload.realized_by_typologies).to eq({"all" => 0})
      end
    
    end
    describe "logement C ->6" do
      let!(:housing_offerL) do
        create(
          :housing_offer,
          district: 'Plaisir',
          department: 'Yvelines',
          priority_public: true,
          typology: "T5",
          threshold_type: 'PLUS',
          operation_name: "Bahamas",
          lessor_id: basic_lessor.id,
          agency_id: agency.id
        )
      end
      before :each do
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offerL.lessor_status = 'LOUE'
        housing_offerL.save()
      end
      it 'should has updated correctly' do
        expect(lessor_objective1.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective2.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective3.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective4.reload.realized_by_typologies).to eq({"T1" => 0})
        expect(lessor_objective5.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective6.reload.realized_by_typologies).to eq({"all" => 1})
      end
    
    end
    describe "logement D ->no obj" do
      let!(:housing_offerL) do
        create(
          :housing_offer,
          district: 'Rambouillet',
          department: 'Yvelines',
          priority_public: true,
          typology: "T2",
          operation_name: "autre",
          lessor_id: basic_lessor.id,
          agency_id: agency.id
        )
      end
      before :each do
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offerL.lessor_status = 'LOUE'
        housing_offerL.save()
      end
      it 'should has updated correctly' do
        expect(lessor_objective1.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective2.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective3.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective4.reload.realized_by_typologies).to eq({"T1" => 0})
        expect(lessor_objective5.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective6.reload.realized_by_typologies).to eq({"all" => 0})
      end
    
    end
    describe "logement E ->no_obj" do
      let!(:housing_offerL) do
        create(
          :housing_offer,
          district: 'Paris',
          department: 'PARIS',
          priority_public: true,
          typology: "T5",
          threshold_type: 'PLUS',
          operation_name: "Bahamas",
          lessor_id: basic_lessor.id,
          agency_id: agency.id
        )
      end
      before :each do
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offerL.lessor_status = 'LOUE'
        housing_offerL.save()
      end
      it 'should has updated correctly' do
        expect(lessor_objective1.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective2.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective3.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective4.reload.realized_by_typologies).to eq({"T1" => 0})
        expect(lessor_objective5.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective6.reload.realized_by_typologies).to eq({"all" => 0})
      end
    
    end
    describe "logement F ->1" do
      let!(:housing_offerL) do
        create(
          :housing_offer,
          district: 'Rambouillet',
          department: 'Yvelines',
          priority_public: true,
          typology: "T2",
          threshold_type: 'PLUS',
          operation_name: "autre",
          lessor_id: basic_lessor.id,
          agency_id: agency.id
        )
      end
      before :each do
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offerL.lessor_status = 'LOUE'
        housing_offerL.save()
      end
      it 'should has updated correctly' do
        expect(lessor_objective1.reload.realized_by_typologies).to eq({"T2" => 1})
        expect(lessor_objective2.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective3.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective4.reload.realized_by_typologies).to eq({"T1" => 0})
        expect(lessor_objective5.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective6.reload.realized_by_typologies).to eq({"all" => 0})
      end
    
    end
    describe "logement G ->4" do
      let!(:housing_offerL) do
        create(
          :housing_offer,
          district: 'Plaisir',
          department: 'Yvelines',
          priority_public: true,
          typology: "T1",
          operation_name: "autres",
          lessor_id: basic_lessor.id,
          agency_id: agency.id
        )
      end
      before :each do
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offerL.lessor_status = 'LOUE'
        housing_offerL.save()
      end
      it 'should has updated correctly' do
        expect(lessor_objective1.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective2.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective3.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective4.reload.realized_by_typologies).to eq({"T1" => 1})
        expect(lessor_objective5.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective6.reload.realized_by_typologies).to eq({"all" => 0})
      end
    
    end
    describe "logement H ->2" do
      let!(:housing_offerL) do
        create(
          :housing_offer,
          district: 'Plaisir',
          department: 'Yvelines',
          priority_public: false,
          typology: "T2",
          operation_name: "autres",
          lessor_id: basic_lessor.id,
          agency_id: agency.id
        )
      end
      before :each do
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offerL.lessor_status = 'LOUE'
        housing_offerL.save()
      end
      it 'should has updated correctly' do
        expect(lessor_objective1.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective2.reload.realized_by_typologies).to eq({"T2" => 1})
        expect(lessor_objective3.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective4.reload.realized_by_typologies).to eq({"T1" => 0})
        expect(lessor_objective5.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective6.reload.realized_by_typologies).to eq({"all" => 0})
      end
    
    end
    describe "logement i ->no_obj" do
      let!(:housing_offerL) do
        create(
          :housing_offer,
          district: 'Plaisir',
          department: 'Yvelines',
          priority_public: false,
          typology: "T3",
          threshold_type: 'PLUS',
          operation_name: "Bahamas",
          lessor_id: basic_lessor.id,
          agency_id: agency.id
        )
      end
      before :each do
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offerL.lessor_status = 'LOUE'
        housing_offerL.save()
      end
      it 'should has updated correctly' do
        expect(lessor_objective1.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective2.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective3.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective4.reload.realized_by_typologies).to eq({"T1" => 0})
        expect(lessor_objective5.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective6.reload.realized_by_typologies).to eq({"all" => 0})
      end
    
    end
    describe "logement j ->2" do
      let!(:housing_offerL) do
        create(
          :housing_offer,
          district: 'Plaisir',
          department: 'Yvelines',
          priority_public: false,
          typology: "T2",
          threshold_type: 'PLUS',
          operation_name: "Bahamas",
          lessor_id: basic_lessor.id,
          agency_id: agency.id
        )
      end
      before :each do
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offerL.lessor_status = 'LOUE'
        housing_offerL.save()
      end
      it 'should has updated correctly' do
        expect(lessor_objective1.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective2.reload.realized_by_typologies).to eq({"T2" => 1})
        expect(lessor_objective3.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective4.reload.realized_by_typologies).to eq({"T1" => 0})
        expect(lessor_objective5.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective6.reload.realized_by_typologies).to eq({"all" => 0})
      end
    
    end
    describe "logement K ->5" do
      let!(:housing_offerL) do
        create(
          :housing_offer,
          district: 'Plaisir',
          department: 'Yvelines',
          priority_public: true,
          typology: "T2",
          threshold_type: 'PLI',
          operation_name: "Bahamas",
          lessor_id: basic_lessor.id,
          agency_id: agency.id
        )
      end
      before :each do
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offerL.lessor_status = 'LOUE'
        housing_offerL.save()
      end
      it 'should has updated correctly' do
        expect(lessor_objective1.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective2.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective3.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective4.reload.realized_by_typologies).to eq({"T1" => 0})
        expect(lessor_objective5.reload.realized_by_typologies).to eq({"all" => 1})
        expect(lessor_objective6.reload.realized_by_typologies).to eq({"all" => 0})
      end
    
    end
    
    describe "logement L ->no_obj" do
      let!(:housing_offerL) do
        create(
          :housing_offer,
          district: 'Plaisir',
          department: 'Yvelines',
          priority_public: false,
          typology: "T1",
          threshold_type: 'PLI',
          operation_name: "Bahamas",
          lessor_id: basic_lessor.id,
          agency_id: agency.id
        )
      end
      before :each do
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offerL.lessor_status = 'LOUE'
        housing_offerL.save()
      end
      it 'should has updated correctly' do
        expect(lessor_objective1.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective2.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective3.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective4.reload.realized_by_typologies).to eq({"T1" => 0})
        expect(lessor_objective5.reload.realized_by_typologies).to eq({"all" => 0})
        expect(lessor_objective6.reload.realized_by_typologies).to eq({"all" => 0})
      end
    end
  end
  describe "by activation date" do
    let!(:lessor_objective_a) do
      create(
        :lessor_objective,
        district: 'Marseille',
        department: '13',
        target_by_typologies: {T1: 50},
        lessor_id: basic_lessor.id,
        activation_date: DateTime.new(DateTime.current.year, 1, 1).utc,
        agency_id: agency.id,
        test: "a"
      )
    end
    let!(:lessor_objective_b) do
      create(
        :lessor_objective,
        district: 'Marseille',
        department: '13',
        target_by_typologies: {T2: 100},
        lessor_id: basic_lessor.id,
        activation_date: DateTime.new(DateTime.current.year, 1, 1).utc,
        agency_id: agency.id,
        test: "b"
      )
    end
    let!(:lessor_objective_c) do
      create(
        :lessor_objective,
        department: '13',
        target_by_typologies: {all: 500},
        lessor_id: basic_lessor.id,
        activation_date: DateTime.new(DateTime.current.year, 1, 1).utc,
        agency_id: agency.id,
        test: "c"
      )
    end
    
    let!(:housing_offer1) do
      create(
        :housing_offer,
        district: 'Marseille',
        department: '13',
        typology: "T1",
        lessor_id: basic_lessor.id,
        agency_id: agency.id
      )
    end
    let!(:housing_offer2) do
      create(
        :housing_offer,
        district: 'Aix',
        department: '13',
        typology: "T2",
        lessor_id: basic_lessor.id,
        agency_id: agency.id
      )
    end
    let!(:housing_offer3) do
      create(
        :housing_offer,
        district: 'Marseille',
        department: '13',
        typology: "T3",
        lessor_id: basic_lessor.id,
        agency_id: agency.id
      )
    end
    let!(:housing_offer4) do
      create(
        :housing_offer,
        district: 'Aix',
        department: '13',
        typology: "T4",
        lessor_id: basic_lessor.id,
        agency_id: agency.id
      )
    end
    let!(:housing_offer5) do
      create(
        :housing_offer,
        district: 'Martigues',
        department: '13',
        typology: "T2",
        lessor_id: basic_lessor.id,
        agency_id: agency.id
      )
    end
    describe "verif scope" do
      it "scope verification" do
        hos = Hermes::HousingOffer.will_trigger_objective(lessor_objective_c.id)
        expect(hos.length).to eq(4)
        expect(lessor_objective_c.targeted_offers_count).to eq(4)
      end
    end
    describe "first iteration" do
      before :each do
        drain_all_jobs
        
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offer1.lessor_status = 'LOUE'
        housing_offer2.lessor_status = 'LOUE'
        housing_offer3.lessor_status = 'LOUE'
        housing_offer4.lessor_status = 'LOUE'
        housing_offer5.lessor_status = 'LOUE'
        
        housing_offer1.save()
        housing_offer2.save()
        housing_offer3.save()
        housing_offer4.save()
        housing_offer5.save()
      end
      it "verify scope" do
        hos = Hermes::HousingOffer.will_trigger_objective(lessor_objective_c.id)
        expect(hos.length).to eq(0)
        expect(lessor_objective_c.targeted_offers_count).to eq(0)
      end
      it 'should has updated correctly' do
        expect(lessor_objective_a.reload.realized_by_typologies).to eq({"T1" => 1})
        expect(lessor_objective_b.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective_c.reload.realized_by_typologies).to eq({"all" => 4})
      
      end
    end
    describe 'second iteration' do
      let!(:lessor_objective_d) do
        create(
          :lessor_objective,
          district: 'Marseille',
          department: '13',
          target_by_typologies: {T1: 50},
          lessor_id: basic_lessor.id,
          activation_date: DateTime.new(DateTime.current.year, 4, 1).utc,
          agency_id: agency.id,
          test: "d"
        )
      end
      let!(:lessor_objective_e) do
        create(
          :lessor_objective,
          district: 'Marseille',
          department: '13',
          target_by_typologies: {all: 100},
          lessor_id: basic_lessor.id,
          activation_date: DateTime.new(DateTime.current.year, 4, 1).utc,
          agency_id: agency.id,
          test: "e"
        )
      end
      let!(:lessor_objective_f) do
        create(
          :lessor_objective,
          department: '13',
          district: 'Aix',
          target_by_typologies: {all: 100},
          lessor_id: basic_lessor.id,
          activation_date: DateTime.new(DateTime.current.year, 4, 1).utc,
          agency_id: agency.id,
          test: "f"
        )
      end

      before :each do
        drain_all_jobs
        
        # housing_request1.applicant_ids = [applicant2.id]
        housing_offer1.lessor_status = 'LOUE'
        housing_offer2.lessor_status = 'LOUE'
        housing_offer3.lessor_status = 'LOUE'
        housing_offer4.lessor_status = 'LOUE'
        housing_offer5.lessor_status = 'LOUE'
        
        housing_offer1.save()
        housing_offer2.save()
        housing_offer3.save()
        housing_offer4.save()
        housing_offer5.save()
      end
      it 'should has updated correctly' do
        expect(lessor_objective_a.reload.realized_by_typologies).to eq({"T1" => 1})
        expect(lessor_objective_b.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective_c.reload.realized_by_typologies).to eq({"all" => 4})
        expect(lessor_objective_d.reload.realized_by_typologies).to eq({"T1" => 1})
        expect(lessor_objective_e.reload.realized_by_typologies).to eq({"all" => 1})
        expect(lessor_objective_f.reload.realized_by_typologies).to eq({"all" => 2})
      
      end
    end
 
    describe 'third iteration' do
      let!(:lessor_objective_g) do
        create(
          :lessor_objective,
          district: 'Marseille',
          department: '13',
          target_by_typologies: {T1: 50},
          lessor_id: basic_lessor.id,
          activation_date: DateTime.new(DateTime.current.year, 4, 2).utc,
          agency_id: agency.id,
          test: "g"
        )
      end
      let!(:lessor_objective_h) do
        create(
          :lessor_objective,
          district: 'Marseille',
          department: '13',
          target_by_typologies: {all: 100},
          lessor_id: basic_lessor.id,
          activation_date: DateTime.new(DateTime.current.year, 4, 2).utc,
          agency_id: agency.id,
          test: "h"
        )
      end
      let!(:lessor_objective_i) do
        create(
          :lessor_objective,
          department: '13',
          district: 'Aix',
          target_by_typologies: {all: 100},
          lessor_id: basic_lessor.id,
          activation_date: DateTime.new(DateTime.current.year, 4, 2).utc,
          agency_id: agency.id,
          test: "i"
        )
      end
      let!(:lessor_objective_j) do
        create(
          :lessor_objective,
          department: '13',
          target_by_typologies: {all: 400},
          lessor_id: basic_lessor.id,
          activation_date: DateTime.new(DateTime.current.year, 4, 2).utc,
          agency_id: agency.id,
          test: "j"
        )
      end
      before :each do
        drain_all_jobs
        
        housing_offer1.lessor_status = 'LOUE'
        housing_offer2.lessor_status = 'LOUE'
        housing_offer3.lessor_status = 'LOUE'
        housing_offer4.lessor_status = 'LOUE'
        housing_offer5.lessor_status = 'LOUE'
        
        housing_offer1.save()
        housing_offer2.save()
        housing_offer3.save()
        housing_offer4.save()
        housing_offer5.save()
      end
      it 'should has updated correctly' do
        
        expect(lessor_objective_a.reload.realized_by_typologies).to eq({"T1" => 1})
        expect(lessor_objective_b.reload.realized_by_typologies).to eq({"T2" => 0})
        expect(lessor_objective_c.reload.realized_by_typologies).to eq({"all" => 4})
=begin
expect(lessor_objective_d.reload.realized_by_typologies).to eq({"T1" => 1})
          expect(lessor_objective_e.reload.realized_by_typologies).to eq({"all" => 1})
          expect(lessor_objective_f.reload.realized_by_typologies).to eq({"all" => 2})
=end
        
        expect(lessor_objective_g.reload.realized_by_typologies).to eq({"T1" => 1})
        expect(lessor_objective_h.reload.realized_by_typologies).to eq({"all" => 1})
        expect(lessor_objective_i.reload.realized_by_typologies).to eq({"all" => 2})
        expect(lessor_objective_j.reload.realized_by_typologies).to eq({"all" => 1})
      end
    end
  
  end
end
